@@ -14,17 +14,6 @@
 
 #define XS_STRUCT2OBJ(sv, class, obj) if (obj == NULL) {  sv_setsv(sv, &PL_sv_undef); } else {  sv_setref_pv(sv, class, (void *) obj);  }
 
-static void
-call_XS ( pTHX_ void (*subaddr) (pTHX_ CV *), CV * cv, SV ** mark )
-{
-  dSP;
-  PUSHMARK (mark);
-  (*subaddr) (aTHX_ cv);
-  PUTBACK;
-}
-
-#define CALL_BOOT(name)	call_XS (aTHX_ name, cv, mark)
-
 SV *_bless(const char *class, void *obj);
 void _perl_free(void *ptr, void *arg);
 void *_perl_malloc(size_t size, void *arg);
